@@ -4,7 +4,7 @@
  *  Galileo E5a data and pilot Signals
  * \author Marc Sales, 2014. marcsales92(at)gmail.com
  * \based on work from:
- * 		<ul>
+ *          <ul>
  *          <li> Javier Arribas, 2011. jarribas(at)cttc.es
  *          <li> Luis Esteve, 2012. luis(at)epsilon-formacion.com
  *          <li> Marc Molina, 2013. marc.molina.pena@gmail.com
@@ -36,12 +36,11 @@
  */
 
 #include "galileo_e5a_noncoherent_iq_acquisition_caf_cc.h"
-#include <sys/time.h>
 #include <sstream>
 #include <gnuradio/io_signature.h>
 #include <glog/logging.h>
 #include <volk/volk.h>
-#include "gnss_signal_processing.h"
+#include <volk_gnsssdr/volk_gnsssdr.h>
 #include "control_message_factory.h"
 
 using google::LogMessage;
@@ -52,7 +51,7 @@ galileo_e5a_noncoherentIQ_acquisition_caf_cc_sptr galileo_e5a_noncoherentIQ_make
         unsigned int doppler_max, long freq, long fs_in,
         int samples_per_ms, int samples_per_code,
         bool bit_transition_flag,
-        gr::msg_queue::sptr queue, bool dump,
+        bool dump,
         std::string dump_filename,
         bool both_signal_components_,
         int CAF_window_hz_,
@@ -61,7 +60,7 @@ galileo_e5a_noncoherentIQ_acquisition_caf_cc_sptr galileo_e5a_noncoherentIQ_make
 
     return galileo_e5a_noncoherentIQ_acquisition_caf_cc_sptr(
             new galileo_e5a_noncoherentIQ_acquisition_caf_cc(sampled_ms, max_dwells, doppler_max, freq, fs_in, samples_per_ms,
-                    samples_per_code, bit_transition_flag, queue, dump, dump_filename, both_signal_components_, CAF_window_hz_, Zero_padding_));
+                    samples_per_code, bit_transition_flag, dump, dump_filename, both_signal_components_, CAF_window_hz_, Zero_padding_));
 }
 
 galileo_e5a_noncoherentIQ_acquisition_caf_cc::galileo_e5a_noncoherentIQ_acquisition_caf_cc(
@@ -70,7 +69,7 @@ galileo_e5a_noncoherentIQ_acquisition_caf_cc::galileo_e5a_noncoherentIQ_acquisit
         unsigned int doppler_max, long freq, long fs_in,
         int samples_per_ms, int samples_per_code,
         bool bit_transition_flag,
-        gr::msg_queue::sptr queue, bool dump,
+        bool dump,
         std::string dump_filename,
         bool both_signal_components_,
         int CAF_window_hz_,
@@ -79,10 +78,10 @@ galileo_e5a_noncoherentIQ_acquisition_caf_cc::galileo_e5a_noncoherentIQ_acquisit
                     gr::io_signature::make(1, 1, sizeof(gr_complex)),
                     gr::io_signature::make(0, 0, sizeof(gr_complex)))
 {
+    this->message_port_register_out(pmt::mp("events"));
     d_sample_counter = 0;    // SAMPLE COUNTER
     d_active = false;
     d_state = 0;
-    d_queue = queue;
     d_freq = freq;
     d_fs_in = fs_in;
     d_samples_per_ms = samples_per_ms;
@@ -163,7 +162,6 @@ galileo_e5a_noncoherentIQ_acquisition_caf_cc::galileo_e5a_noncoherentIQ_acquisit
     d_code_phase = 0;
     d_doppler_freq = 0;
     d_test_statistics = 0;
-    d_channel_internal_queue = 0;
     d_CAF_vector = 0;
     d_CAF_vector_I = 0;
     d_CAF_vector_Q = 0;
@@ -273,11 +271,18 @@ void galileo_e5a_noncoherentIQ_acquisition_caf_cc::set_local_code(std::complex<f
 
 void galileo_e5a_noncoherentIQ_acquisition_caf_cc::init()
 {
+    d_gnss_synchro->Flag_valid_acquisition = false;
+    d_gnss_synchro->Flag_valid_symbol_output = false;
+    d_gnss_synchro->Flag_valid_pseudorange = false;
+    d_gnss_synchro->Flag_valid_word = false;
+    d_gnss_synchro->Flag_preamble = false;
+
     d_gnss_synchro->Acq_delay_samples = 0.0;
     d_gnss_synchro->Acq_doppler_hz = 0.0;
     d_gnss_synchro->Acq_samplestamp_samples = 0;
     d_mag = 0.0;
     d_input_power = 0.0;
+    const double GALILEO_TWO_PI = 6.283185307179600;
 
     // Count the number of bins
     d_num_doppler_bins = 0;
@@ -294,7 +299,10 @@ void galileo_e5a_noncoherentIQ_acquisition_caf_cc::init()
         {
             d_grid_doppler_wipeoffs[doppler_index] = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
             int doppler = -static_cast<int>(d_doppler_max) + d_doppler_step * doppler_index;
-            complex_exp_gen_conj(d_grid_doppler_wipeoffs[doppler_index], d_freq + doppler, d_fs_in, d_fft_size);
+            float phase_step_rad = GALILEO_TWO_PI * (d_freq + doppler) / static_cast<float>(d_fs_in);
+            float _phase[1];
+            _phase[0] = 0;
+            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], - phase_step_rad, _phase, d_fft_size);
         }
 
     /* CAF Filtering to resolve doppler ambiguity. Phase and quadrature must be processed
@@ -339,7 +347,7 @@ void galileo_e5a_noncoherentIQ_acquisition_caf_cc::set_state(int state)
 
 int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items,
         gr_vector_int &ninput_items, gr_vector_const_void_star &input_items,
-        gr_vector_void_star &output_items)
+        gr_vector_void_star &output_items __attribute__((unused)))
 {
     /*
      * By J.Arribas, L.Esteve, M.Molina and M.Sales
@@ -350,15 +358,15 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
      * 4. OPTIONAL: CAF filter to avoid doppler ambiguity
      * 5. Record the maximum peak and the associated synchronization parameters
      * 6. Compute the test statistics and compare to the threshold
-     * 7. Declare positive or negative acquisition using a message queue
+     * 7. Declare positive or negative acquisition using a message port
      */
 
     int acquisition_message = -1; //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
-    /* States: 	0 Stop Channel
-     * 		1 Load the buffer until it reaches fft_size
-     * 		2 Acquisition algorithm
-     * 		3 Positive acquisition
-     * 		4 Negative acquisition
+    /* States:     0 Stop Channel
+     *         1 Load the buffer until it reaches fft_size
+     *         2 Acquisition algorithm
+     *         3 Positive acquisition
+     *         4 Negative acquisition
      */
     switch (d_state)
     {
@@ -416,11 +424,19 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
 
             // initialize acquisition algorithm
             int doppler;
+#if VOLK_GT_122
+            uint16_t indext = 0;
+            uint16_t indext_IA = 0;
+            uint16_t indext_IB = 0;
+            uint16_t indext_QA = 0;
+            uint16_t indext_QB = 0;
+#else
             unsigned int indext = 0;
             unsigned int indext_IA = 0;
             unsigned int indext_IB = 0;
             unsigned int indext_QA = 0;
             unsigned int indext_QB = 0;
+#endif
             float magt = 0.0;
             float magt_IA = 0.0;
             float magt_IB = 0.0;
@@ -647,7 +663,7 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
                     // weighting_factor = 0;
                     // std::cout << "weighting_factor " << weighting_factor << std::endl;
                     // Initialize first iterations
-                    for (int doppler_index=0; doppler_index < CAF_bins_half; doppler_index++)
+                    for (int doppler_index = 0; doppler_index < CAF_bins_half; doppler_index++)
                         {
                             d_CAF_vector[doppler_index] = 0;
                             // volk_32f_accumulator_s32f_a(&d_CAF_vector[doppler_index], d_CAF_vector_I, CAF_bins_half+doppler_index+1);
@@ -656,7 +672,7 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
                                     d_CAF_vector[doppler_index] += d_CAF_vector_I[i] * (1 - weighting_factor * static_cast<unsigned int>((doppler_index - i)));
                                 }
                             // d_CAF_vector[doppler_index] /= CAF_bins_half+doppler_index+1;
-                            d_CAF_vector[doppler_index] /= 1 + CAF_bins_half+doppler_index - weighting_factor * CAF_bins_half * (CAF_bins_half + 1) / 2 - weighting_factor*doppler_index*(doppler_index+1)/2; // triangles = [n*(n+1)/2]
+                            d_CAF_vector[doppler_index] /= 1 + CAF_bins_half + doppler_index - weighting_factor * CAF_bins_half * (CAF_bins_half + 1) / 2 - weighting_factor * doppler_index * (doppler_index + 1) / 2; // triangles = [n*(n+1)/2]
                             if (d_both_signal_components)
                                 {
                                     accum[0] = 0;
@@ -671,21 +687,21 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
                                 }
                         }
                     // Body loop
-                    for (unsigned int doppler_index = CAF_bins_half;doppler_index<d_num_doppler_bins-CAF_bins_half;doppler_index++)
+                    for (unsigned int doppler_index = CAF_bins_half; doppler_index < d_num_doppler_bins - CAF_bins_half; doppler_index++)
                         {
                             d_CAF_vector[doppler_index] = 0;
-                            //				volk_32f_accumulator_s32f_a(&d_CAF_vector[doppler_index], &d_CAF_vector_I[doppler_index-CAF_bins_half], 2*CAF_bins_half+1);
-                            for (int i = doppler_index-CAF_bins_half; i < doppler_index+CAF_bins_half + 1; i++)
+                            // volk_32f_accumulator_s32f_a(&d_CAF_vector[doppler_index], &d_CAF_vector_I[doppler_index-CAF_bins_half], 2*CAF_bins_half+1);
+                            for (int i = doppler_index - CAF_bins_half; i < static_cast<int>(doppler_index + CAF_bins_half + 1); i++)
                                 {
-                                    d_CAF_vector[doppler_index] += d_CAF_vector_I[i] * (1-weighting_factor * static_cast<unsigned int>((doppler_index - i)));
+                                    d_CAF_vector[doppler_index] += d_CAF_vector_I[i] * (1 - weighting_factor * static_cast<unsigned int>((doppler_index - i)));
                                 }
-                            //				d_CAF_vector[doppler_index] /= 2*CAF_bins_half+1;
+                            // d_CAF_vector[doppler_index] /= 2*CAF_bins_half+1;
                             d_CAF_vector[doppler_index] /= 1 + 2 * CAF_bins_half - 2 * weighting_factor * CAF_bins_half * (CAF_bins_half + 1) / 2;
                             if (d_both_signal_components)
                                 {
                                     accum[0] = 0;
                                     // volk_32f_accumulator_s32f_a(&accum[0], &d_CAF_vector_Q[doppler_index-CAF_bins_half], 2*CAF_bins_half);
-                                    for (int i = doppler_index-CAF_bins_half; i < doppler_index + CAF_bins_half + 1; i++)
+                                    for (int i = doppler_index-CAF_bins_half; i < static_cast<int>(doppler_index + CAF_bins_half + 1); i++)
                                         {
                                             accum[0] += d_CAF_vector_Q[i] * (1 - weighting_factor * static_cast<unsigned int>((doppler_index - i)));
                                         }
@@ -695,11 +711,11 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
                                 }
                         }
                     // Final iterations
-                    for (int doppler_index = d_num_doppler_bins - CAF_bins_half; doppler_index < d_num_doppler_bins; doppler_index++)
+                    for (int doppler_index = d_num_doppler_bins - CAF_bins_half; doppler_index < static_cast<int>(d_num_doppler_bins); doppler_index++)
                         {
                             d_CAF_vector[doppler_index] = 0;
                             // volk_32f_accumulator_s32f_a(&d_CAF_vector[doppler_index], &d_CAF_vector_I[doppler_index-CAF_bins_half], CAF_bins_half + (d_num_doppler_bins-doppler_index));
-                            for (int i = doppler_index - CAF_bins_half; i < d_num_doppler_bins; i++)
+                            for (int i = doppler_index - CAF_bins_half; i < static_cast<int>(d_num_doppler_bins); i++)
                                 {
                                     d_CAF_vector[doppler_index] += d_CAF_vector_I[i] * (1 - weighting_factor * (abs(doppler_index - i)));
                                 }
@@ -709,7 +725,7 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
                                 {
                                     accum[0] = 0;
                                     // volk_32f_accumulator_s32f_a(&accum[0], &d_CAF_vector_Q[doppler_index-CAF_bins_half], CAF_bins_half + (d_num_doppler_bins-doppler_index));
-                                    for (int i = doppler_index-CAF_bins_half; i < d_num_doppler_bins; i++)
+                                    for (int i = doppler_index-CAF_bins_half; i < static_cast<int>(d_num_doppler_bins); i++)
                                         {
                                             accum[0] += d_CAF_vector_Q[i] * (1 - weighting_factor * (abs(doppler_index - i)));
                                         }
@@ -759,7 +775,7 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
         }
     case 3:
         {
-            // 7.1- Declare positive acquisition using a message queue
+            // 7.1- Declare positive acquisition using a message port
             DLOG(INFO) << "positive acquisition";
             DLOG(INFO) << "satellite " << d_gnss_synchro->System << " " << d_gnss_synchro->PRN;
             DLOG(INFO) << "sample_stamp " << d_sample_counter;
@@ -774,14 +790,14 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
             d_state = 0;
 
             acquisition_message = 1;
-            d_channel_internal_queue->push(acquisition_message);
+            this->message_port_pub(pmt::mp("events"), pmt::from_long(acquisition_message));
             d_sample_counter += ninput_items[0]; // sample counter
             consume_each(ninput_items[0]);
             break;
         }
     case 4:
         {
-            // 7.2- Declare negative acquisition using a message queue
+            // 7.2- Declare negative acquisition using a message port
             DLOG(INFO) << "negative acquisition";
             DLOG(INFO) << "satellite " << d_gnss_synchro->System << " " << d_gnss_synchro->PRN;
             DLOG(INFO) << "sample_stamp " << d_sample_counter;
@@ -798,7 +814,7 @@ int galileo_e5a_noncoherentIQ_acquisition_caf_cc::general_work(int noutput_items
             d_sample_counter += ninput_items[0]; // sample counter
             consume_each(ninput_items[0]);
             acquisition_message = 2;
-            d_channel_internal_queue->push(acquisition_message);
+            this->message_port_pub(pmt::mp("events"), pmt::from_long(acquisition_message));
             break;
         }
     }
