@@ -35,11 +35,11 @@
 #include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <volk/volk.h>
-#include "nco_lib.h"
+#include <volk_gnsssdr/volk_gnsssdr.h>
 #include "concurrent_map.h"
-#include "gnss_signal_processing.h"
 #include "control_message_factory.h"
 #include "gps_acq_assist.h"
+#include "GPS_L1_CA.h"
 
 extern concurrent_map<Gps_Acq_Assist> global_gps_acq_assist_map;
 
@@ -47,28 +47,27 @@ using google::LogMessage;
 
 pcps_assisted_acquisition_cc_sptr pcps_make_assisted_acquisition_cc(
         int max_dwells, unsigned int sampled_ms, int doppler_max, int doppler_min, long freq,
-        long fs_in, int samples_per_ms, boost::shared_ptr<gr::msg_queue> queue, bool dump,
+        long fs_in, int samples_per_ms, bool dump,
         std::string dump_filename)
 {
-
     return pcps_assisted_acquisition_cc_sptr(
             new pcps_assisted_acquisition_cc(max_dwells, sampled_ms, doppler_max, doppler_min, freq,
-                    fs_in, samples_per_ms, queue, dump, dump_filename));
+                    fs_in, samples_per_ms, dump, dump_filename));
 }
 
 
 
 pcps_assisted_acquisition_cc::pcps_assisted_acquisition_cc(
         int max_dwells, unsigned int sampled_ms, int doppler_max, int doppler_min, long freq,
-        long fs_in, int samples_per_ms, boost::shared_ptr<gr::msg_queue> queue, bool dump,
+        long fs_in, int samples_per_ms, bool dump,
         std::string dump_filename) :
-		        gr::block("pcps_assisted_acquisition_cc",
-		                gr::io_signature::make(1, 1, sizeof(gr_complex)),
-		                gr::io_signature::make(0, 0, sizeof(gr_complex)))
+                gr::block("pcps_assisted_acquisition_cc",
+                        gr::io_signature::make(1, 1, sizeof(gr_complex)),
+                        gr::io_signature::make(0, 0, sizeof(gr_complex)))
 {
+    this->message_port_register_out(pmt::mp("events"));
     d_sample_counter = 0;    // SAMPLE COUNTER
     d_active = false;
-    d_queue = queue;
     d_freq = freq;
     d_fs_in = fs_in;
     d_samples_per_ms = samples_per_ms;
@@ -107,7 +106,6 @@ pcps_assisted_acquisition_cc::pcps_assisted_acquisition_cc(
     d_code_phase = 0;
     d_doppler_freq = 0;
     d_test_statistics = 0;
-    d_channel_internal_queue = 0;
     d_well_count = 0;
     d_channel = 0;
 }
@@ -156,6 +154,12 @@ void pcps_assisted_acquisition_cc::set_local_code(std::complex<float> * code)
 
 void pcps_assisted_acquisition_cc::init()
 {
+    d_gnss_synchro->Flag_valid_acquisition = false;
+    d_gnss_synchro->Flag_valid_symbol_output = false;
+    d_gnss_synchro->Flag_valid_pseudorange = false;
+    d_gnss_synchro->Flag_valid_word = false;
+    d_gnss_synchro->Flag_preamble = false;
+
     d_gnss_synchro->Acq_delay_samples = 0.0;
     d_gnss_synchro->Acq_doppler_hz = 0.0;
     d_gnss_synchro->Acq_samplestamp_samples = 0;
@@ -173,7 +177,10 @@ void pcps_assisted_acquisition_cc::init()
 void pcps_assisted_acquisition_cc::forecast (int noutput_items,
         gr_vector_int &ninput_items_required)
 {
-    ninput_items_required[0] = d_gnuradio_forecast_samples ; //set the required available samples in each call
+    if (noutput_items != 0)
+        {
+            ninput_items_required[0] = d_gnuradio_forecast_samples ; //set the required available samples in each call
+        }
 }
 
 
@@ -248,7 +255,9 @@ void pcps_assisted_acquisition_cc::redefine_grid()
             // compute the carrier doppler wipe-off signal and store it
             phase_step_rad = static_cast<float>(GPS_TWO_PI) * doppler_hz / static_cast<float>(d_fs_in);
             d_grid_doppler_wipeoffs[doppler_index] = new gr_complex[d_fft_size];
-            fxp_nco(d_grid_doppler_wipeoffs[doppler_index], d_fft_size, 0, phase_step_rad);
+            float _phase[1];
+            _phase[0] = 0;
+            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], - phase_step_rad, _phase, d_fft_size);
         }
 }
 
@@ -259,8 +268,13 @@ double pcps_assisted_acquisition_cc::search_maximum()
     float magt = 0.0;
     float fft_normalization_factor;
     int index_doppler = 0;
-    unsigned int tmp_intex_t;
+#if VOLK_GT_122
+    uint16_t tmp_intex_t;
+    uint16_t index_time = 0;
+#else
+    unsigned int tmp_intex_t = 0;
     unsigned int index_time = 0;
+#endif
 
     for (int i=0;i<d_num_doppler_points;i++)
         {
@@ -365,23 +379,23 @@ int pcps_assisted_acquisition_cc::compute_and_accumulate_grid(gr_vector_const_vo
 
 int pcps_assisted_acquisition_cc::general_work(int noutput_items,
         gr_vector_int &ninput_items, gr_vector_const_void_star &input_items,
-        gr_vector_void_star &output_items)
+        gr_vector_void_star &output_items __attribute__((unused)))
 {
     /*!
-     * TODO: 	High sensitivity acquisition algorithm:
-     * 			State Mechine:
-     * 			S0. StandBy. If d_active==1 -> S1
-     * 			S1. GetAssist. Define search grid with assistance information. Reset grid matrix -> S2
-     * 			S2. ComputeGrid. Perform the FFT acqusition doppler and delay grid.
-     * 				Accumulate the search grid matrix (#doppler_bins x #fft_size)
-     * 				Compare maximum to threshold and decide positive or negative
-     * 				If T>=gamma -> S4 else
-     * 				If d_well_count<max_dwells -> S2
-     * 				else if !disable_assist -> S3
-     * 				else -> S5.
-     * 			S3. RedefineGrid. Open the grid search to unasisted acquisition. Reset counters and grid. -> S2
-     * 			S4. Positive_Acq: Send message and stop acq -> S0
-     * 			S5. Negative_Acq: Send message and stop acq -> S0
+     * TODO:     High sensitivity acquisition algorithm:
+     *             State Mechine:
+     *             S0. StandBy. If d_active==1 -> S1
+     *             S1. GetAssist. Define search grid with assistance information. Reset grid matrix -> S2
+     *             S2. ComputeGrid. Perform the FFT acqusition doppler and delay grid.
+     *                 Accumulate the search grid matrix (#doppler_bins x #fft_size)
+     *                 Compare maximum to threshold and decide positive or negative
+     *                 If T>=gamma -> S4 else
+     *                 If d_well_count<max_dwells -> S2
+     *                 else if !disable_assist -> S3
+     *                 else -> S5.
+     *             S3. RedefineGrid. Open the grid search to unasisted acquisition. Reset counters and grid. -> S2
+     *             S4. Positive_Acq: Send message and stop acq -> S0
+     *             S5. Negative_Acq: Send message and stop acq -> S0
      */
 
     switch (d_state)
@@ -451,8 +465,8 @@ int pcps_assisted_acquisition_cc::general_work(int noutput_items,
         DLOG(INFO) << "doppler " << d_gnss_synchro->Acq_doppler_hz;
         DLOG(INFO) << "input signal power " << d_input_power;
         d_active = false;
-        // Send message to channel queue //0=STOP_CHANNEL 1=ACQ_SUCCESS 2=ACQ_FAIL
-        d_channel_internal_queue->push(1); // 1-> positive acquisition
+        // Send message to channel port //0=STOP_CHANNEL 1=ACQ_SUCCESS 2=ACQ_FAIL
+        this->message_port_pub(pmt::mp("events"), pmt::from_long(1));
         free_grid_memory();
         // consume samples to not block the GNU Radio flowgraph
         d_sample_counter += ninput_items[0]; // sample counter
@@ -469,8 +483,8 @@ int pcps_assisted_acquisition_cc::general_work(int noutput_items,
         DLOG(INFO) << "doppler " << d_gnss_synchro->Acq_doppler_hz;
         DLOG(INFO) << "input signal power " << d_input_power;
         d_active = false;
-        // Send message to channel queue //0=STOP_CHANNEL 1=ACQ_SUCCESS 2=ACQ_FAIL
-        d_channel_internal_queue->push(2); // 2-> negative acquisition
+        // Send message to channel port //0=STOP_CHANNEL 1=ACQ_SUCCESS 2=ACQ_FAIL
+        this->message_port_pub(pmt::mp("events"), pmt::from_long(2));
         free_grid_memory();
         // consume samples to not block the GNU Radio flowgraph
         d_sample_counter += ninput_items[0]; // sample counter
