@@ -29,15 +29,14 @@
  */
 
 #include "pcps_quicksync_acquisition_cc.h"
-#include <ctime>
 #include <cmath>
 #include <sstream>
 #include <gnuradio/io_signature.h>
 #include <glog/logging.h>
 #include <volk/volk.h>
+#include <volk_gnsssdr/volk_gnsssdr.h>
 #include "control_message_factory.h"
-#include "gnss_signal_processing.h"
-
+#include "GPS_L1_CA.h"
 
 
 using google::LogMessage;
@@ -48,10 +47,9 @@ pcps_quicksync_acquisition_cc_sptr pcps_quicksync_make_acquisition_cc(
         unsigned int doppler_max, long freq, long fs_in,
         int samples_per_ms, int samples_per_code,
         bool bit_transition_flag,
-        gr::msg_queue::sptr queue, bool dump,
+        bool dump,
         std::string dump_filename)
 {
-
     return pcps_quicksync_acquisition_cc_sptr(
             new pcps_quicksync_acquisition_cc(
                     folding_factor,
@@ -59,27 +57,25 @@ pcps_quicksync_acquisition_cc_sptr pcps_quicksync_make_acquisition_cc(
                     freq, fs_in, samples_per_ms,
                     samples_per_code,
                     bit_transition_flag,
-                    queue, dump, dump_filename));
+                    dump, dump_filename));
 }
 
+
 pcps_quicksync_acquisition_cc::pcps_quicksync_acquisition_cc(
         unsigned int folding_factor,
         unsigned int sampled_ms, unsigned int max_dwells,
         unsigned int doppler_max, long freq, long fs_in,
         int samples_per_ms, int samples_per_code,
         bool bit_transition_flag,
-        gr::msg_queue::sptr queue, bool dump,
-        std::string dump_filename):
+        bool dump, std::string dump_filename):
            gr::block("pcps_quicksync_acquisition_cc",
                gr::io_signature::make(1, 1, (sizeof(gr_complex)*sampled_ms * samples_per_ms )),
                gr::io_signature::make(0, 0, (sizeof(gr_complex)*sampled_ms * samples_per_ms )))
 {
-    //DLOG(INFO) << "START CONSTRUCTOR";
-
+    this->message_port_register_out(pmt::mp("events"));
     d_sample_counter = 0;    // SAMPLE COUNTER
     d_active = false;
     d_state = 0;
-    d_queue = queue;
     d_freq = freq;
     d_fs_in = fs_in;
     d_samples_per_ms = samples_per_ms;
@@ -130,13 +126,13 @@ pcps_quicksync_acquisition_cc::pcps_quicksync_acquisition_cc(
     d_code_phase = 0;
     d_doppler_freq = 0;
     d_test_statistics = 0;
-    d_channel_internal_queue = 0;
     d_channel = 0;
     //d_code_folded = 0;
 
     // DLOG(INFO) << "END CONSTRUCTOR";
 }
 
+
 pcps_quicksync_acquisition_cc::~pcps_quicksync_acquisition_cc()
 {
     //DLOG(INFO) << "START DESTROYER";
@@ -197,6 +193,12 @@ void pcps_quicksync_acquisition_cc::set_local_code(std::complex<float>* code)
 
 void pcps_quicksync_acquisition_cc::init()
 {
+    d_gnss_synchro->Flag_valid_acquisition = false;
+    d_gnss_synchro->Flag_valid_symbol_output = false;
+    d_gnss_synchro->Flag_valid_pseudorange = false;
+    d_gnss_synchro->Flag_valid_word = false;
+    d_gnss_synchro->Flag_preamble = false;
+
     //DLOG(INFO) << "START init";
     d_gnss_synchro->Acq_delay_samples = 0.0;
     d_gnss_synchro->Acq_doppler_hz = 0.0;
@@ -221,9 +223,10 @@ void pcps_quicksync_acquisition_cc::init()
         {
             d_grid_doppler_wipeoffs[doppler_index] = static_cast<gr_complex*>(volk_malloc(d_samples_per_code * d_folding_factor * sizeof(gr_complex), volk_get_alignment()));
             int doppler = -static_cast<int>(d_doppler_max) + d_doppler_step * doppler_index;
-            complex_exp_gen_conj(d_grid_doppler_wipeoffs[doppler_index],
-                    d_freq + doppler, d_fs_in,
-                    d_samples_per_code * d_folding_factor);
+            float phase_step_rad = GPS_TWO_PI * (d_freq + doppler) / static_cast<float>(d_fs_in);
+            float _phase[1];
+            _phase[0] = 0;
+            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], - phase_step_rad, _phase, d_samples_per_code * d_folding_factor);
         }
     // DLOG(INFO) << "end init";
 }
@@ -253,7 +256,7 @@ void pcps_quicksync_acquisition_cc::set_state(int state)
 
 int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
         gr_vector_int &ninput_items, gr_vector_const_void_star &input_items,
-        gr_vector_void_star &output_items)
+        gr_vector_void_star &output_items __attribute__((unused)))
 {
     /*
      * By J.Arribas, L.Esteve and M.Molina
@@ -298,7 +301,11 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
             /* initialize acquisition  implementing the QuickSync algorithm*/
             //DLOG(INFO) << "START CASE 1";
             int doppler;
+#if VOLK_GT_122
+            uint16_t indext = 0;
+#else
             unsigned int indext = 0;
+#endif
             float magt = 0.0;
             const gr_complex *in = (const gr_complex *)input_items[0]; //Get the input samples pointer
 
@@ -474,8 +481,8 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
                             std::streamsize n =  sizeof(float) * (d_fft_size); // complex file write
                             filename.str("");
                             filename << "../data/test_statistics_" << d_gnss_synchro->System
-                                     << "_" << d_gnss_synchro->Signal << "_sat_"
-                                     << d_gnss_synchro->PRN << "_doppler_" <<  doppler << ".dat";
+                                    << "_" << d_gnss_synchro->Signal << "_sat_"
+                                    << d_gnss_synchro->PRN << "_doppler_" <<  doppler << ".dat";
                             d_dump_file.open(filename.str().c_str(), std::ios::out | std::ios::binary);
                             d_dump_file.write((char*)d_magnitude_folded, n); //write directly |abs(x)|^2 in this Doppler bin?
                             d_dump_file.close();
@@ -522,7 +529,7 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
     case 2:
         {
             //DLOG(INFO) << "START CASE 2";
-            // 6.1- Declare positive acquisition using a message queue
+            // 6.1- Declare positive acquisition using a message port
             DLOG(INFO) << "positive acquisition";
             DLOG(INFO) << "satellite " << d_gnss_synchro->System << " " << d_gnss_synchro->PRN;
             DLOG(INFO) << "sample_stamp " << d_sample_counter;
@@ -543,7 +550,7 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
             consume_each(ninput_items[0]);
 
             acquisition_message = 1;
-            d_channel_internal_queue->push(acquisition_message);
+            this->message_port_pub(pmt::mp("events"), pmt::from_long(acquisition_message));
             //DLOG(INFO) << "END CASE 2";
             break;
         }
@@ -551,14 +558,14 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
     case 3:
         {
             //DLOG(INFO) << "START CASE 3";
-            // 6.2- Declare negative acquisition using a message queue
+            // 6.2- Declare negative acquisition using a message port
             DLOG(INFO) << "negative acquisition";
             DLOG(INFO) << "satellite " << d_gnss_synchro->System << " " << d_gnss_synchro->PRN;
             DLOG(INFO) << "sample_stamp " << d_sample_counter;
             DLOG(INFO) << "test statistics value " << d_test_statistics;
             DLOG(INFO) << "test statistics threshold " << d_threshold;
             DLOG(INFO) << "folding factor "<<d_folding_factor;
-            DLOG(INFO) << "possible delay	corr output";
+            DLOG(INFO) << "possible delay    corr output";
             for (int i = 0; i < static_cast<int>(d_folding_factor); i++) DLOG(INFO) << d_possible_delay[i] << "\t\t\t" << d_corr_output_f[i];
             DLOG(INFO) << "code phase " << d_gnss_synchro->Acq_delay_samples;
             DLOG(INFO) << "doppler " << d_gnss_synchro->Acq_doppler_hz;
@@ -572,11 +579,10 @@ int pcps_quicksync_acquisition_cc::general_work(int noutput_items,
             consume_each(ninput_items[0]);
 
             acquisition_message = 2;
-            d_channel_internal_queue->push(acquisition_message);
+            this->message_port_pub(pmt::mp("events"), pmt::from_long(acquisition_message));
             //DLOG(INFO) << "END CASE 3";
             break;
         }
     }
-    //DLOG(INFO) << "END GENERAL WORK";
     return noutput_items;
 }
