@@ -54,9 +54,6 @@ public:
     virtual Gnss_Signal get_signal() const = 0;
     virtual void start_acquisition() = 0;
     virtual void set_signal(const Gnss_Signal&) = 0;
-    virtual void start() = 0;
-    virtual void standby() = 0;
-    virtual void stop() = 0;
 };
 
 #endif /* GNSS_SDR_CHANNEL_INTERFACE_H_ */
